@@ -3,7 +3,7 @@ from pprint import pformat
 from pytezos.crypto import blake2b_32
 from pytezos.operation.content import ContentMixin
 from pytezos.operation.forge import forge_operation_group
-from pytezos.operation.fees import calculate_fee, default_fee, default_gas_limit, default_storage_limit, burn_cap
+from pytezos.operation.fees import calculate_fee, default_fee, default_gas_limit, default_storage_limit
 from pytezos.operation.result import OperationResult
 from pytezos.rpc.errors import RpcError
 from pytezos.encoding import forge_base58, base58_encode
@@ -26,6 +26,9 @@ validation_passes = {
 
 
 class OperationGroup(Interop, ContentMixin):
+    """ Operation group representation: contents (single or multiple), signature, other fields,
+    and also useful helpers for filling with precise fees, signing, forging, and injecting.
+    """
 
     def __init__(self, contents=None, protocol=None, chain_id=None, branch=None, signature=None, shell=None, key=None):
         super(OperationGroup, self).__init__(shell=shell, key=key)
@@ -57,9 +60,7 @@ class OperationGroup(Interop, ContentMixin):
         )
 
     def json_payload(self) -> dict:
-        """
-        Get json payload used for preapply.
-        :return: dic
+        """ Get json payload used for the preapply.
         """
         return {
             'protocol': self.protocol,
@@ -69,9 +70,7 @@ class OperationGroup(Interop, ContentMixin):
         }
 
     def binary_payload(self) -> bytes:
-        """
-        Get binary payload used for injection/hash calculation.
-        :return: bytes
+        """ Get binary payload used for injection/hash calculation.
         """
         if not self.signature:
             raise ValueError('Not signed')
@@ -79,18 +78,18 @@ class OperationGroup(Interop, ContentMixin):
         return bytes.fromhex(self.forge()) + forge_base58(self.signature)
 
     def operation(self, content):
-        """
-        Create new operation group with extra content added.
+        """ Create new operation group with extra content added.
+
         :param content: Kind-specific operation body
-        :return: OperationGroup
+        :rtype: OperationGroup
         """
         return self._spawn(contents=self.contents + [content])
 
     def fill(self):
-        """
-        Try to fill all fields left unfilled, use approximate fees
+        """ Try to fill all fields left unfilled, use approximate fees
         (not optimal, use `autofill` to simulate operation and get precise values).
-        :return: OperationGroup
+
+        :rtype: OperationGroup
         """
         chain_id = self.chain_id or self.shell.chains.main.chain_id()
         branch = self.branch or self.shell.head.predecessor.hash()
@@ -127,9 +126,9 @@ class OperationGroup(Interop, ContentMixin):
         )
 
     def run(self):
-        """
-        Simulate operation without signature checks.
-        :return: RPC response
+        """ Simulate operation without signature checks.
+
+        :returns: RPC response from `run_operation`
         """
         return self.shell.head.helpers.scripts.run_operation.post({
             'operation': {
@@ -141,10 +140,10 @@ class OperationGroup(Interop, ContentMixin):
         })
 
     def forge(self, validate=True):
-        """
-        Convert json representation of the operation group into bytes
+        """ Convert json representation of the operation group into bytes.
+
         :param validate: Forge remotely also and compare results, default is True
-        :return: Hex string
+        :returns: Hex string
         """
         payload = {
             'branch': self.branch,
@@ -160,10 +159,10 @@ class OperationGroup(Interop, ContentMixin):
         return local_data
 
     def autofill(self, gas_reserve=100):
-        """
-        Fill the gaps and then simulate the operation in order to calculate fee, gas/storage limits.
+        """ Fill the gaps and then simulate the operation in order to calculate fee, gas/storage limits.
+
         :param gas_reserve: Add a safe reserve for gas limit (default is 100)
-        :return: OperationGroup
+        :rtype: OperationGroup
         """
         opg = self.fill()
         opg_with_metadata = opg.run()
@@ -176,10 +175,11 @@ class OperationGroup(Interop, ContentMixin):
             if validation_passes[content['kind']] == 3:
                 consumed_gas = OperationResult.consumed_gas(content) + gas_reserve
                 paid_storage_size_diff = OperationResult.paid_storage_size_diff(content)
+                burned = OperationResult.burned(content)
                 fee = calculate_fee(content, consumed_gas, extra_size)
                 content.update(
                     gas_limit=str(consumed_gas + gas_reserve),
-                    storage_limit=str(paid_storage_size_diff + burn_cap(content)),
+                    storage_limit=str(paid_storage_size_diff + burned),
                     fee=str(fee)
                 )
 
@@ -190,9 +190,9 @@ class OperationGroup(Interop, ContentMixin):
         return opg
 
     def sign(self):
-        """
-        Sign the operation group with the key specified by `using`.
-        :return: OperationGroup
+        """ Sign the operation group with the key specified by `using`.
+
+        :rtype: OperationGroup
         """
         validation_pass = validation_passes[self.contents[0]['kind']]
         if any(map(lambda x: validation_passes[x['kind']] != validation_pass, self.contents)):
@@ -209,18 +209,16 @@ class OperationGroup(Interop, ContentMixin):
 
         return self._spawn(signature=signature)
 
-    def hash(self):
-        """
-        Calculate the Base58 encoded operation group hash.
-        :return: str
+    def hash(self) -> str:
+        """ Calculate the Base58 encoded operation group hash.
         """
         hash_digest = blake2b_32(self.binary_payload()).digest()
         return base58_encode(hash_digest, b'o').decode()
 
     def preapply(self):
-        """
-        Preapply signed operation group.
-        :return: RPC response
+        """ Preapply signed operation group.
+
+        :returns: RPC response from `preapply`
         """
         if not self.signature:
             raise ValueError('Not signed')
@@ -229,12 +227,13 @@ class OperationGroup(Interop, ContentMixin):
             operations=[self.json_payload()])[0]
 
     def inject(self, _async=True, preapply=True, check_result=True, num_blocks_wait=2):
-        """
-        Inject signed operation group.
+        """ Inject the signed operation group.
+
         :param _async: do not wait for operation inclusion (default is True)
-        :param preapply:
-        :param check_result:
-        :param num_blocks_wait:
+        :param preapply: do a preapply before injection
+        :param check_result: raise RpcError in case operation is refused
+        :param num_blocks_wait: number of blocks to wait for injection
+        :returns: operation group with metadata (raw RPC response)
         """
         if preapply:
             opg_with_metadata = self.preapply()
@@ -268,8 +267,8 @@ class OperationGroup(Interop, ContentMixin):
         raise TimeoutError(opg_hash)
 
     def result(self):
-        """
-        Parse preapply result
-        :return: OperationResult
+        """ Parse the preapply result.
+
+        :rtype: OperationResult
         """
         return OperationResult.from_operation_group(self.preapply())
