@@ -150,6 +150,9 @@ def format_stderr(error):
 
 
 class Interpreter:
+    """ Michelson interpreter reimplemented in Python.
+    Based on the following reference: https://michelson.nomadic-labs.com/
+    """
 
     def __init__(self, debug=True):
         self.ctx = Context()
@@ -157,6 +160,11 @@ class Interpreter:
         self.debug = debug
 
     def execute(self, code):
+        """ Execute Michelson instructions (note that stack is not cleared after execution).
+
+        :param code: Michelson source (any valid Michelson expression or special helpers)
+        :returns: {"success": True|False, "stdout": "", "stderr": {}, "result": {"value": "", ...}}
+        """
         int_res = {'success': False}
 
         try:
